@@ -13,15 +13,15 @@ our %EXPORT_TAGS = (
 	Constants => [qw(RHASH_CRC32 RHASH_MD4 RHASH_MD5 RHASH_SHA1 RHASH_TIGER
 		RHASH_TTH RHASH_BTIH RHASH_ED2K RHASH_AICH RHASH_WHIRLPOOL
 		RHASH_RIPEMD160 RHASH_GOST RHASH_GOST_CRYPTOPRO RHASH_HAS160
-		RHASH_SNEFRU128 RHASH_SNEFRU256 RHASH_SHA224 RHASH_SHA256 RHASH_SHA384
-		RHASH_SHA512 RHASH_EDONR256 RHASH_EDONR512 RHASH_ALL
-		RHPR_DEFAULT RHPR_RAW RHPR_HEX RHPR_BASE32 RHPR_BASE64 RHPR_UPPERCASE RHPR_REVERSE)]
+		RHASH_SNEFRU128 RHASH_SNEFRU256 RHASH_SHA224 RHASH_SHA256
+		RHASH_SHA384 RHASH_SHA512 RHASH_EDONR256 RHASH_EDONR512
+		RHASH_SHA3_224 RHASH_SHA3_256 RHASH_SHA3_384 RHASH_SHA3_512 RHASH_ALL)]
 );
 
 Exporter::export_tags( );
 Exporter::export_ok_tags( qw(Functions Constants) );
 
-our $VERSION = '0.90';
+our $VERSION = '0.91';
 
 require XSLoader;
 XSLoader::load('Crypt::Rhash', $VERSION);
@@ -50,7 +50,11 @@ use constant RHASH_SHA384    => 0x40000;
 use constant RHASH_SHA512    => 0x80000;
 use constant RHASH_EDONR256  => 0x100000;
 use constant RHASH_EDONR512  => 0x200000;
-use constant RHASH_ALL       => 0x3FFFFF;
+use constant RHASH_SHA3_224  => 0x0400000;
+use constant RHASH_SHA3_256  => 0x0800000;
+use constant RHASH_SHA3_384  => 0x1000000;
+use constant RHASH_SHA3_512  => 0x2000000;
+use constant RHASH_ALL       => 0x3FFFFFF;
 
 ##############################################################################
 # Rhash class methods
@@ -229,39 +233,43 @@ __END__
 
 =head1 NAME
 
-Rhash - Perl extension for LibRHash Hash library
+Crypt::Rhash - Compute hash sums and magnet links
 
 =head1 SYNOPSIS
 
-  use Rhash;
+  use Crypt::Rhash;
   
   my $msg = "a message text";
-  print "MD5 = " . Rhash->new(RHASH_MD5)->update($msg)->hash() . "\n";
+  print "MD5 = " . Crypt::Rhash::msg(RHASH_MD5, $msg) . "\n";
   
-  # more complex example - calculate two hash functions simultaniously
-  my $r = Rhash->new(RHASH_MD5 | RHASH_SHA1);
+  # Calculate two hash functions simultaneously
+  my $r = Crypt::Rhash->new(RHASH_MD5 | RHASH_SHA1);
   $r->update("a message text")->update(" another message");
-  print  "MD5  = ". $r->hash(RHASH_MD5) . "\n";
-  print  "SHA1 = ". $r->hash(RHASH_SHA1) . "\n";
+  print  "MD5  = " . $r->hash(RHASH_MD5) . "\n";
+  print  "SHA1 = " . $r->hash(RHASH_SHA1) . "\n";
 
 =head1 DESCRIPTION
 
-Rhash module is an object-oriented interface to the LibRHash library,
-which allows one to simultaniously calculate several hash functions for a file or a text message.
+Crypt::Rhash module is an object-oriented interface to the LibRHash library,
+allowing simultaneous calculation of several hash functions for a file  or a
+text message.
+
+Resulting hash digest can be obtained in hexadecimal, BASE32, BASE64, raw
+binary format or as a magnet link.
 
 =head1 SUPPORTED ALGORITHMS
 
 The module supports the following hashing algorithms:
-CRC32,  MD4, MD5,  SHA1, SHA256, SHA512,
+CRC32,  MD4, MD5,  SHA1, SHA256, SHA512, SHA3,
 AICH, ED2K, Tiger,  DC++ TTH,  BitTorrent BTIH, GOST R 34.11-94, RIPEMD-160,
 HAS-160, EDON-R 256/512, Whirlpool and Snefru-128/256.
 
 =head1 CONSTRUCTOR
 
-Creates and returns new Rhash object.
+Creates and returns new Crypt::Rhash object.
 
-  my $r = Rhash->new($hash_id);
-  my $p = new Rhash($hash_id); # alternative way to call the constructor
+  my $r = Crypt::Rhash->new($hash_id);
+  my $p = new Crypt::Rhash($hash_id); # alternative way to call the constructor
 
 The $hash_id parameter can be union (via bitwise OR) of any of the following bit-flags:
 
@@ -285,11 +293,15 @@ The $hash_id parameter can be union (via bitwise OR) of any of the following bit
   RHASH_SHA256,
   RHASH_SHA384,
   RHASH_SHA512,
+  RHASH_SHA3_224,
+  RHASH_SHA3_256,
+  RHASH_SHA3_384,
+  RHASH_SHA3_512,
   RHASH_EDONR256,
   RHASH_EDONR512
 
 Also the RHASH_ALL bit mask is the union of all listed bit-flags.
-So the object created via Rhash->new(RHASH_ALL) calculates all
+So the object created via Crypt::Rhash->new(RHASH_ALL) calculates all
 supported hash functions for the same data.
 
 =head1 COMPUTING HASHES
@@ -302,7 +314,7 @@ Calculates hashes of the $msg string.
 The method can be called repeatedly with chunks of the message to be hashed.
 It returns the $rhash object itself allowing the following construct:
 
-  $rhash = Rhash->new(RHASH_MD5)->update( $chunk1 )->update( $chunk2 );
+  $rhash = Crypt::Rhash->new(RHASH_MD5)->update( $chunk1 )->update( $chunk2 );
 
 =item $rhash->update_file( $file_path, $start, $size )
 
@@ -311,13 +323,13 @@ It returns the $rhash object itself allowing the following construct:
 Calculate a hash of the file (or its part) specified by $file_path or a file descriptor $fd.
 The update_fd method doesn't close the $fd, leaving the file position after the hashed block.
 The optional $start and $size specify the block of the file to hash.
-No error is reported if the $size is grater than the number of the unread bytes left in the file.
+No error is reported if the $size is greater than the number of the unread bytes left in the file.
 
 Returns the number of characters actually read, 0 at end of file, 
 or undef if there was an error (in the latter case $! is also set).
 
-  use Rhash;
-  my $r = new Rhash(RHASH_SHA1);
+  use Crypt::Rhash;
+  my $r = new Crypt::Rhash(RHASH_SHA1);
   open(my $fd, "<", "input.txt") or die "cannot open < input.txt: $!";
   while ((my $n = $r->update_fd($fd, undef, 1024) != 0) {
       print "$n bytes hashed. The SHA1 hash is " . $r->final()->hash() . "\n";
@@ -348,7 +360,7 @@ Returns the hash mask, the $rhash object was constructed with.
 
 =head1 FORMATING HASH VALUE
 
-Computed hash can be formated as a hexadecimal string (in the forward or
+Computed hash can be formatted as a hexadecimal string (in the forward or
 reverse byte order), a base32/base64-encoded string or as raw binary data.
 
 =over
@@ -356,30 +368,34 @@ reverse byte order), a base32/base64-encoded string or as raw binary data.
 =item $rhash->hash( $hash_id )
 
 Returns the hash string in the default format,
-which can be hexadecimal or base32. Actually the method is equvalent of
+which can be hexadecimal or base32. Actually the method is equivalent of
 
   (Crypt::Rhash::is_base32($hash_id) ? $rhash->hash_base32($hash_id) :
     $rhash->hash_hex($hash_id))
 
-If the optional $hash_id parameter is omited or zero, then the method returns the hash
+If the optional $hash_id parameter is omitted or zero, then the method returns the hash
 for the algorithm contained in $rhash with the lowest identifier.
 
 =item $rhash->hash_hex( $hash_id )
 
-Returns a specified hash in the hexadecimal format.
+Returns the specified hash in the hexadecimal format.
+
+  use Crypt::Rhash;
+  my $msg = "abc";
+  print "MD5 = " . Crypt::Rhash->new(RHASH_MD5)->update($msg)->hash_hex() . "\n";
 
 =item $rhash->hash_rhex( $hash_id )
 
-Returns a hexadecimal string of the hash in reversed bytes order.
-Some programs prefer to output GOST hash in this format.
+Returns the specified hash in the hexadecimal format with reversed order of bytes.
+Some programs prefer to output the GOST R 34.11-94 hash in this format.
 
 =item $rhash->hash_base32( $hash_id )
 
-Returns a specified hash in the base32 format.
+Returns the specified hash in the base32 format.
 
 =item $rhash->hash_base64( $hash_id )
 
-Returns a specified hash in the base64 format.
+Returns the specified hash in the base64 format.
 
 =item $rhash->magnet_link( $filename, $hash_mask )
 
@@ -391,7 +407,7 @@ into the link.
 
 =back
 
-=head1 STATIC INFORMATION METHODS
+=head1 STATIC METHODS
 
 =over
 
@@ -402,7 +418,7 @@ Returns the number of supported hash algorithms
 =item Crypt::Rhash::is_base32($hash_id)
 
 Returns nonzero if default output format is Base32 for the hash function specified by $hash_id.
-Retruns zero if default format is hexadecimal.
+Returns zero if default format is hexadecimal.
 
 =item Crypt::Rhash::get_digest_size($hash_id)
 
@@ -426,8 +442,8 @@ Returns the name of the specified hash algorithm.
 
 Computes and returns a single hash (in its default format) of the $message by the selected hash algorithm.
 
-  use Rhash;
-  print "SHA1( 'abc' ) = " . Crypt::Rhash::msg(RHASH_SHA1, "abc");
+  use Crypt::Rhash;
+  print "SHA1( 'abc' ) = " . Crypt::Rhash::msg(RHASH_SHA1, "abc") . "\n";
 
 =back
 
@@ -443,3 +459,5 @@ Computes and returns a single hash (in its default format) of the $message by th
  The Software  is distributed in the hope that it will be useful,  but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  Use  this  program  at  your  own  risk!
+
+=cut
